/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.extension.artifactrepository.api;

import java.io.File;
import java.util.List;

import org.ow2.petals.basisapi.exception.PetalsException;

/**
 * The artifact repository is used to have a reference on some JBI artefacts.
 * 
 * @author Christophe HAMERLING - EBM WebSourcing
 * 
 */
public interface ArtifactRepositoryService {

    public static final String COMPONENT_LOGGER_NAME = "Petals.Extensions.ArtifactRepositoryService";

    /**
     * The name set to the Fractal composite associated to the Petals ESB
     * Artifact Repository
     */
    public static final String ARTIFACTREPOSITORY_COMPONENT_NAME = "ArtifactRepository";

    /**
     * The name of the server interface of the Fractal composite associated to
     * the Petals ESB Artifact Repository
     */
    public static final String SERVICE_FRACTAL_ITF_NAME = "service";

    /**
     * The name of the extension for logging and dependency purposes.
     */
    public final static String EXTENSION_NAME = "Petals ESB Artifact Repository";

    /**
     * Get the artifact repository root path
     * 
     * @return
     */
    File getRootPath();

    /**
     * 
     * @return
     */
    File getComponentsPath();

    /**
     * 
     * @return
     */
    File getServiceAssemblyPath();

    /**
     * 
     * @return
     */
    File getSharedLibraryPath();

    /**
     * Get the list of components which are available in the repository
     * 
     * @return
     */
    List<Artifact> getComponents();

    /**
     * 
     * @return
     */
    public List<String> getComponentsName();

    /**
     * 
     * @return
     */
    List<Artifact> getServiceAssemblies();

    /**
     * 
     * @return
     */
    public List<String> getServiceAssembliesName();

    /**
     * 
     * @return
     */
    List<Artifact> getSharedLibraries();

    /**
     * 
     * @return
     */
    public List<String> getSharedLibrariesName();

    /**
     * Add the artifact to the repository
     * 
     * @param artifact
     * @return
     */
    boolean addArtifact(Artifact artifact) throws PetalsException;

}
